@@ -17,7 +17,7 @@ You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 """
-__version__ = '0.0.3'
+__version__ = '0.0.4'
 __url__ = "http://joey101.net/gooeypy/"
 __doc__ = """
 GooeyPy is the result of my need for a flexible and easy to use gui for pygame. Yes, I realize there are already guis for pygame out there. But with each one there is something I don't like. GooeyPy simply has everything the way I like it. So I'm not going to say it's the best one out there, because everyone has their own opinions. Here are some things that are different about GooeyPy:
@@ -38,18 +38,4 @@ Effects:
     I like the ability to have cool effects applied to my widgets. Now I have them.
 """
 
-from util import get_image, init, update_rects, blit, update_display
 
-from app import App
-from widget import Widget
-from container import Container
-from button import Button, Switch
-from input import Input
-from label import Label
-from slider import HSlider, VSlider
-from selectbox import SelectBox
-from box import VBox, HBox
-from const import *
-from styleset import StyleSet
-from textblock import TextBlock
-from image import Image
